@@ -54,6 +54,7 @@ grn_ctx grn_gctx = GRN_CTX_INITIALIZER(GRN_ENC_DEFAULT);
 int grn_pagesize;
 grn_critical_section grn_glock;
 uint32_t grn_gtick;
+int grn_lock_timeout = GRN_LOCK_TIMEOUT;
 
 #ifdef USE_UYIELD
 int grn_uyield_count = 0;
@@ -1217,6 +1218,18 @@ check_overcommit_memory(grn_ctx *ctx)
   fclose(file);
 }
 
+static void
+check_grn_ja_skip_same_value_put(grn_ctx *ctx)
+{
+  const char *grn_ja_skip_same_value_put_env;
+
+  grn_ja_skip_same_value_put_env = getenv("GRN_JA_SKIP_SAME_VALUE_PUT");
+  if (grn_ja_skip_same_value_put_env &&
+      strcmp(grn_ja_skip_same_value_put_env, "no") == 0) {
+    grn_ja_skip_same_value_put = GRN_FALSE;
+  }
+}
+
 grn_rc
 grn_init(void)
 {
@@ -1247,21 +1260,6 @@ grn_init(void)
     GRN_LOG(ctx, GRN_LOG_CRIT, "pagesize=%x", grn_pagesize);
   }
   // expand_stack();
-#ifdef USE_AIO
-  if (getenv("GRN_DEBUG_PRINT")) {
-    grn_debug_print = atoi(getenv("GRN_DEBUG_PRINT"));
-  } else {
-    grn_debug_print = 0;
-  }
-  if (getenv("GRN_AIO_ENABLED")) {
-    grn_aio_enabled = atoi(getenv("GRN_AIO_ENABLED"));
-  } else {
-    grn_aio_enabled = 0;
-  }
-  if (grn_aio_enabled) {
-    GRN_LOG(ctx, GRN_LOG_NOTICE, "AIO and DIO enabled");
-  }
-#endif /* USE_AIO */
 #ifdef USE_FAIL_MALLOC
   if (getenv("GRN_FMALLOC_PROB")) {
     grn_fmalloc_prob = strtod(getenv("GRN_FMALLOC_PROB"), 0) * RAND_MAX;
@@ -1311,6 +1309,7 @@ grn_init(void)
   grn_cache_init();
   GRN_LOG(ctx, GRN_LOG_NOTICE, "grn_init");
   check_overcommit_memory(ctx);
+  check_grn_ja_skip_same_value_put(ctx);
   return rc;
 }
 
@@ -1364,6 +1363,19 @@ grn_set_default_match_escalation_threshold(long long int threshold)
   return grn_ctx_set_match_escalation_threshold(&grn_gctx, threshold);
 }
 
+int
+grn_get_lock_timeout(void)
+{
+  return grn_lock_timeout;
+}
+
+grn_rc
+grn_set_lock_timeout(int timeout)
+{
+  grn_lock_timeout = timeout;
+  return GRN_SUCCESS;
+}
+
 static int alloc_count = 0;
 
 grn_rc
