@@ -113,14 +113,18 @@
 #include <sys/types.h>
 
 #ifndef __GNUC__
-#define PATH_MAX (MAX_PATH - 1)
-#define inline _inline
+# define PATH_MAX (MAX_PATH - 1)
+# ifndef __cplusplus
+#  define inline _inline
+# endif
 #endif
 
-#define snprintf(str, size, ...) _snprintf(str, size, __VA_ARGS__)
-#if _MSC_VER < 1500
+#ifndef __GNUC__
+# define snprintf(str, size, ...) _snprintf(str, size, __VA_ARGS__)
+#endif /* __GNUC__ */
+#if !defined(__GNUC__) && _MSC_VER < 1500
 # define vsnprintf(str, size, format, ap) _vsnprintf(str, size, format, ap)
-#endif /* _MSC_VER < 1500 */
+#endif /* !defined(__GNUC__) && _MSC_VER < 1500 */
 #define unlink(pathname) _unlink(pathname)
 #define lseek(fd, offset, whence) _lseek(fd, offset, whence)
 #define getpid() _getpid()
@@ -152,16 +156,6 @@
 #define MSG_WAITALL 0 /* before Vista, not supported... */
 #define SHUT_RDWR SD_BOTH
 
-#ifdef HAVE_FPCLASSIFY
-# define CASE_FP_NAN case FP_NAN:
-# define CASE_FP_INFINITE case FP_INFINITE:
-#else
-# define HAVE_FPCLASSIFY 1
-# define fpclassify _fpclass
-# define CASE_FP_NAN case _FPCLASS_SNAN: case _FPCLASS_QNAN:
-# define CASE_FP_INFINITE case _FPCLASS_NINF: case _FPCLASS_PINF:
-#endif /* HAVE_FPCLASSIFY */
-
 typedef SOCKET grn_sock;
 #define grn_sock_close(sock) closesocket(sock)
 
@@ -198,19 +192,6 @@ typedef int grn_sock;
 # define grn_sock_close(sock) close(sock)
 # define CALLBACK
 
-# ifdef HAVE_FPCLASSIFY
-#  define CASE_FP_NAN case FP_NAN:
-#  define CASE_FP_INFINITE case FP_INFINITE:
-# else
-#  if (defined(__sun) && defined(__SVR4)) /* SUN */
-#   define HAVE_FPCLASSIFY 1
-#   include <ieeefp.h>
-#   define fpclassify fpclass
-#   define CASE_FP_NAN case FP_SNAN: case FP_QNAN:
-#   define CASE_FP_INFINITE case FP_NINF: case FP_PINF:
-#  endif /* SUN */
-# endif /* HAVE_FPCLASSIFY */
-
 #endif /* WIN32 */
 
 #ifndef INT8_MAX
@@ -260,12 +241,16 @@ typedef pthread_mutex_t grn_mutex;
 #define MUTEX_LOCK(m)   pthread_mutex_lock(&m)
 #define MUTEX_UNLOCK(m) pthread_mutex_unlock(&m)
 #define MUTEX_FIN(m)
-#define MUTEX_INIT_SHARED(m) do {\
+#ifdef HAVE_PTHREAD_MUTEXATTR_SETPSHARED
+# define MUTEX_INIT_SHARED(m) do {\
   pthread_mutexattr_t mutexattr;\
   pthread_mutexattr_init(&mutexattr);\
   pthread_mutexattr_setpshared(&mutexattr, PTHREAD_PROCESS_SHARED);\
   pthread_mutex_init(&m, &mutexattr);\
 } while (0)
+#else
+# define MUTEX_INIT_SHARED MUTEX_INIT
+#endif /* HAVE_PTHREAD_MUTEXATTR_SETPSHARED */
 
 typedef pthread_mutex_t grn_critical_section;
 #define CRITICAL_SECTION_INIT(cs)  pthread_mutex_init(&(cs), NULL)
@@ -278,12 +263,16 @@ typedef pthread_cond_t grn_cond;
 #define COND_SIGNAL(c) pthread_cond_signal(&c)
 #define COND_WAIT(c,m) pthread_cond_wait(&c, &m)
 #define COND_BROADCAST(c) pthread_cond_broadcast(&c)
-#define COND_INIT_SHARED(c) do {\
+#ifdef HAVE_PTHREAD_CONDATTR_SETPSHARED
+# define COND_INIT_SHARED(c) do {\
   pthread_condattr_t condattr;\
   pthread_condattr_init(&condattr);\
   pthread_condattr_setpshared(&condattr, PTHREAD_PROCESS_SHARED);\
   pthread_cond_init(&c, &condattr);\
 } while (0)
+#else
+# define COND_INIT_SHARED COND_INIT
+#endif /* HAVE_PTHREAD_CONDATTR_SETPSHARE */
 
 typedef pthread_key_t grn_thread_key;
 #define THREAD_KEY_CREATE(key, destr)  pthread_key_create(key, destr)
