@@ -46,7 +46,7 @@ grn_str_charlen_utf8(grn_ctx *ctx, const unsigned char *str, const unsigned char
     }
     if (str + len > end) {
       GRN_LOG(ctx, GRN_LOG_WARNING,
-              "grn_str_charlen_utf8(): imcomplete character");
+              "grn_str_charlen_utf8(): incomplete character");
       return 0;
     }
     for (i = 1; i < len; ++i) {
@@ -2099,10 +2099,10 @@ grn_text_ftoa(grn_ctx *ctx, grn_obj *buf, double d)
   }
 #ifdef HAVE_FPCLASSIFY
   switch (fpclassify(d)) {
-  CASE_FP_NAN
+  case FP_NAN :
     GRN_TEXT_PUTS(ctx, buf, "#<nan>");
     break;
-  CASE_FP_INFINITE
+  case FP_INFINITE :
     GRN_TEXT_PUTS(ctx, buf, d > 0 ? "#i1/0" : "#i-1/0");
     break;
   default :
@@ -2721,7 +2721,9 @@ grn_text_otoj(grn_ctx *ctx, grn_obj *bulk, grn_obj *obj, grn_obj_format *format)
         if (table && table->header.type != GRN_TABLE_NO_KEY) {
           /* todo : temporal patch. grn_table_at() is kinda costful... */
           if (grn_table_at(ctx, table, id)) {
-            grn_obj *accessor = grn_obj_column(ctx, table, "_key", 4);
+            grn_obj *accessor = grn_obj_column(ctx, table,
+                                               GRN_COLUMN_NAME_KEY,
+                                               GRN_COLUMN_NAME_KEY_LEN);
             if (accessor) {
               grn_obj_get_value(ctx, accessor, id, &buf);
               grn_obj_unlink(ctx, accessor);
@@ -2952,7 +2954,9 @@ grn_text_otoj(grn_ctx *ctx, grn_obj *bulk, grn_obj *obj, grn_obj_format *format)
     } else {
       int i;
       grn_id id;
-      grn_obj *column = grn_obj_column(ctx, obj, "_key", 4);
+      grn_obj *column = grn_obj_column(ctx, obj,
+                                       GRN_COLUMN_NAME_KEY,
+                                       GRN_COLUMN_NAME_KEY_LEN);
       grn_table_cursor *tc = grn_table_cursor_open(ctx, obj, NULL, 0, NULL, 0,
                                                    0, -1, GRN_CURSOR_ASCENDING);
       GRN_TEXT_PUTC(ctx, bulk, '[');
