@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2; coding: utf-8 -*- */
 /*
-  Copyright (C) 2010-2011  Kouhei Sutou <kou@clear-code.com>
+  Copyright (C) 2010-2012  Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -13,7 +13,7 @@
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #include <gcutter.h>
@@ -23,18 +23,23 @@
 
 #include <str.h>
 
-void test_by_id(void);
-void test_by_filter(void);
-void test_by_invalid_filter(void);
-void test_by_id_and_filter(void);
-void test_by_all_options(void);
-void test_by_key(void);
-void test_referenced_record(void);
+void test_id(void);
+void test_filter(void);
+void test_key(void);
 void test_uint64(void);
 void test_last_token(void);
 void test_no_key_twice(void);
 void test_no_key_by_id(void);
 void test_corrupt_jagged_array(void);
+void test_no_table_name(void);
+void test_nonexistent_table(void);
+void test_no_selector(void);
+void test_all_selector(void);
+void test_key_and_id(void);
+void test_key_and_filter(void);
+void test_id_and_filter(void);
+void test_invalid_id(void);
+void test_invalid_filter(void);
 
 static gchar *tmp_directory;
 
@@ -117,7 +122,7 @@ cut_teardown(void)
 }
 
 void
-test_by_id(void)
+test_id(void)
 {
   assert_send_command("delete Users --id 1");
   cut_assert_equal_string("[[[3],"
@@ -130,7 +135,7 @@ test_by_id(void)
 }
 
 void
-test_by_filter(void)
+test_filter(void)
 {
   assert_send_command("delete Users --filter "
                         "\"_key == \\\"tapo\\\"\"");
@@ -144,37 +149,7 @@ test_by_filter(void)
 }
 
 void
-test_by_invalid_filter(void)
-{
-  grn_test_assert_send_command_error(
-    context,
-    GRN_SYNTAX_ERROR,
-    "Syntax error! ($)",
-    "delete Users --filter \"$\"");
-}
-
-void
-test_by_id_and_filter(void)
-{
-  grn_test_assert_send_command_error(
-    context,
-    GRN_INVALID_ARGUMENT,
-    "filter is used with id and/or key",
-    "delete Users --id 1 --filter \"true\"");
-}
-
-void
-test_by_all_options(void)
-{
-  grn_test_assert_send_command_error(
-    context,
-    GRN_INVALID_ARGUMENT,
-    "filter is used with id and/or key",
-    "delete Users --id 1 --key mori --filter \"true\"");
-}
-
-void
-test_by_delete(void)
+test_key(void)
 {
   assert_send_command("delete Users tapo");
   cut_assert_equal_string("[[[3],"
@@ -186,23 +161,6 @@ test_by_delete(void)
                                        "--output_columns _key"));
 }
 
-void
-test_referenced_record(void)
-{
-  assert_send_command_error(GRN_OPERATION_NOT_PERMITTED,
-                            "undeletable record (Users:4) "
-                            "has value (bookmarks:1)",
-                            "delete Users tasukuchan");
-  cut_assert_equal_string("[[[2],"
-                            "[[\"_key\",\"ShortText\"]],"
-                            "[\"tapo\"],"
-                            "[\"tasukuchan\"]]]",
-                          send_command("select Users "
-                                       "--output_columns _key "
-                                       "--match_columns \"_key\" "
-                                       "--query \"ta\""));
-}
-
 void
 test_uint64(void)
 {
@@ -330,3 +288,101 @@ test_corrupt_jagged_array(void)
                     text_129bytes),
                     send_command("select Sites"));
 }
+
+void
+test_no_table_name(void)
+{
+  grn_test_assert_send_command_error(
+    context,
+    GRN_INVALID_ARGUMENT,
+    "[table][record][delete] table name isn't specified",
+    "delete");
+}
+
+void
+test_nonexistent_table(void)
+{
+  grn_test_assert_send_command_error(
+    context,
+    GRN_INVALID_ARGUMENT,
+    "[table][record][delete] table doesn't exist: <nonexistent>",
+    "delete nonexistent");
+}
+
+void
+test_no_selector(void)
+{
+  grn_test_assert_send_command_error(
+    context,
+    GRN_INVALID_ARGUMENT,
+    "[table][record][delete] either key, id or filter must be specified: "
+    "table: <Users>",
+    "delete Users");
+}
+
+void
+test_all_selector(void)
+{
+  grn_test_assert_send_command_error(
+    context,
+    GRN_INVALID_ARGUMENT,
+    "[table][record][delete] "
+    "record selector must be one of key, id and filter: "
+    "table: <Users>, key: <mori>, id: <1>, filter: <true>",
+    "delete Users --key mori --id 1 --filter \"true\"");
+}
+
+void
+test_key_and_id(void)
+{
+  grn_test_assert_send_command_error(
+    context,
+    GRN_INVALID_ARGUMENT,
+    "[table][record][delete] can't use both key and id: "
+    "table: <Users>, key: <mori>, id: <1>",
+    "delete Users --key mori --id 1");
+}
+
+void
+test_key_and_filter(void)
+{
+  grn_test_assert_send_command_error(
+    context,
+    GRN_INVALID_ARGUMENT,
+    "[table][record][delete] can't use both key and filter: "
+    "table: <Users>, key: <mori>, filter: <true>",
+    "delete Users --key mori --filter true");
+}
+
+void
+test_id_and_filter(void)
+{
+  grn_test_assert_send_command_error(
+    context,
+    GRN_INVALID_ARGUMENT,
+    "[table][record][delete] can't use both id and filter: "
+    "table: <Users>, id: <1>, filter: <true>",
+    "delete Users --id 1 --filter true");
+}
+
+void
+test_invalid_id(void)
+{
+  grn_test_assert_send_command_error(
+    context,
+    GRN_INVALID_ARGUMENT,
+    "[table][record][delete] id should be number: "
+    "table: <Users>, id: <1x2>, detail: <1|x|2>",
+    "delete Users --id \"1x2\"");
+}
+
+void
+test_invalid_filter(void)
+{
+  grn_test_assert_send_command_error(
+    context,
+    GRN_SYNTAX_ERROR,
+    "[table][record][delete] failed to parse filter: "
+    "table: <Users>, filter: <$>, detail: <Syntax error! ($)>",
+    "delete Users --filter \"$\"");
+}
